# frozen_string_literal: true

module Hermes
  module BoClient
    # extending Mapping Module from base_map.rb
    module Mappings
      # handle HousingOffer model mapping for xml data send
      class HousingOfferMap
        include Hermes::BoClient::Mappings::Concerns::BaseMap
        
        def initialize(options)
          housing_offer_id = options[:housing_offer_id]
          applicant_id = options[:applicant_id]
          self.main_object = Hermes::HousingOffer.find_by(id: housing_offer_id)
          raise ArgumentError, "Offer with #{housing_offer_id} doesn't exists." unless main_object
          
          @agency = Hermes::Entity.find_by(id: main_object.agency_id)
          @applicant = Hermes::Applicant.find_by(id: applicant_id) unless applicant_id.nil?
          
          @map = {
              'SIREN_ALS': 'als_siren',
              'reference_offre': 'id',
              
              'orientation_bailleur': 'lessor_orientation', # missing from import
              'reference': 'external_ref',
              'id_rpls': 'lessor.rpls_id',
              'texte': 'description',
              'adresse': 'address',
              'adresse_complement': 'address_complements',
              
              'code_postal': 'postal_code',
              'departement': 'department',
              'ville': 'district',
              'code_residence': 'residence_code',
              'libelle_residence': 'residence_title',
              'latitude': 'latitude',
              'longitude': 'longitude',
              
              'type_construction': 'construction_type',
              'nature': 'kind',
              'type': 'typology',
              
              'dpe_etiquette_ges': 'dpe_ges',
              'dpe_etiquette_conso': 'dpe_conso',
              
              'zone_plafond_ressources': 'threshold_subtype',
              'type_chauffage': 'heating_type',
              'eau_chaude_distribution': 'hot_water_distribution', # missing from import
              
              'nature_stationnement': 'parking_type',
              'visite_virtuelle': 'virtual_visit',
              
              
              'cave': 'cellars',
              'type_cuisine': 'kitchen_type',
              'loyer_mensuel': 'rent_amount',
              'charges_locatives': 'rental_charges',
              
              'acces_handicapes': 'disability_accesses',
              
              'positionnement_quartile_1': 'first_quartile',
              'positionnement_quartiles_autres': 'other_quartiles',
              'public_prioritaire': 'priority_public',
              'ref_convention_reservation': 'reservation_agreement_ref', # missing from import
              'raison_sociale_reservataire': 'reserving_business_name',
              'SIREN_reservataire': 'reserving_siren',
              
              'libelle_agence': 'agency_name',
              'contact_a_afficher': 'lessor_contact_name',
              'email_a_afficher': 'lessor_email',
              'telephone_a_afficher': 'lessor_phone_number',
              'id_externe_pdv': 'agency_id'
          }
        end
        
        def plafond_ressources
          main_object&.threshold&.codes&.fetch(0)
        end
        
        def visite_virtuelle
          main_object&.virtual_visit ? "O" : "N"
        end
        
        def meuble
          main_object&.furnished_lodging ? "O" : "N"
        end
        
        def balcon_terrasse
          main_object&.terraces_or_balconies ? "O" : "N"
        end
        
        def SIREN_bailleur
          main_object&.lessor&.siret&.slice(0, 8)
        end
        
        def libelle_organisme
          main_object&.lessor&.title
        end
        
        def loyer_mensuel_cc
          main_object&.rent_with_charges&.round(2)
        end
        
        # def libelle_agence
        #   main_object&.agency&.title
        # end
        def espace_vert
          main_object&.green_area ? "O" : "N"
        end
        
        def deja_loue
          main_object&.already_inhabited ? "O" : "N"
        end
        
        def communiquer_adresse_exacte
          main_object&.communicate_exact_address ? "O" : "N"
        end
        
        def copropriete
          return if main_object&.condo == nil
          main_object&.condo ? 'O' : 'N'
        end
        
        def QPV
          main_object&.qpv ? "O" : "N"
        end
        
        def jardin
          main_object&.has_garden ? "O" : "N"
        end
        
        def ascenseur
          main_object&.has_elevator ? "O" : "N"
        end
        
        def duplex
          main_object&.duplex ? "O" : "N"
        end
        
        def presence_gardien
          main_object&.has_gardian ? "O" : "N"
        end
        
        def annee_construction
          main_object&.construction_year ? main_object&.construction_year.year : nil
        end
        
        def etage
          main_object&.floor || 0
        end
        
        def nb_etage
          main_object&.floors || 0
        end
        
        def nbr_salle_bain
          main_object&.bathrooms || 1
        end
        
        def nb_pieces_logement
          main_object&.rooms || 1
        end
        
        def depot_garantie
          main_object&.guarantee_deposit || 0
        end
        
        # def contact_a_afficher
        #   main_object&.main_contact&.superfields&.fetch('given_name')
        # end
        def latitude
          main_object&.latitude || 0
        end
        
        def longitude
          main_object&.longitude || 0
        end
        
        def loyer_stationnement_cc
          res = main_object&.parking_charges
          if (res && res != 0.0 && res != "0.0")
            res
          else
            return nil
          end
        end
        
        def date_disponibilite
          main_object&.availability_date&.to_date
        end
        
        def date_fin_designation
          main_object&.designation_date_end&.to_date
        end
        
        def date_MAD_ALS
          main_object&.is_mad_updated_at&.to_date
        end
        
        def surface
          main_object&.surface || 0
        
        end
        
        def photos
          photos = []
          main_object&.ordered_pictures&.each do |picture|
            #photos.push(Asset.public_relative_url(picture.full_size_id.to_s).to_s) if (picture.full_size_id)
            photos.push("pat_FRAM.jpg")
          end
          return photos
        end
      
      end
    end
  end
end
